# AAP

A Python library for registering an IP address on a specific server.

## Installation

To install AAP lib from PyPI, run: pip install aap_utils


## Usage

```python
from aap_utils import register_demo

register_demo(debug=True)

